import argparse
import logging
import logging.config
import os.path
import subprocess

import requests

from . import shuffle

CACHE_DIR = os.path.expanduser('~/.cache/desktopography')  # TODO(fbochu) XDG and config
GSETTINGS = {
    'cinnamon': 'org.cinnamon.desktop.background',
    'gnome': 'org.gnome.desktop.background',
}


def set_logger():
    logging.config.dictConfig({
        'version': 1,
        'formatters': {
            'simple': {
                'format': '%(asctime)s - %(message)s',
            },
        },
        'handlers': {
            'console': {
                'class': 'logging.StreamHandler',
                'formatter': 'simple',
            },
        },
        'loggers': {
            'desktopography': {
                'level': 'INFO',
                'handlers': ['console'],
            },
        },
    })


def store(wallpaper_url):
    if not os.path.exists(CACHE_DIR):
        os.makedirs(CACHE_DIR)

    filename = wallpaper_url.rsplit('/')[-1]
    file_path = os.path.join(CACHE_DIR, filename)
    with open(file_path, 'wb') as fp:
        fp.write(requests.get(wallpaper_url).content)

    return file_path


def gsettings(desktop, size):
    wallpaper_url = shuffle.select_random_wallpaper(size)
    wallpaper_path = store(wallpaper_url)
    subprocess.call([
        'gsettings', 'set',
        GSETTINGS[desktop], 'picture-uri',
        'file://{}'.format(wallpaper_path),
    ])
    return wallpaper_path


def main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(dest='command')
    subparser = subparsers.add_parser('shuffle')
    subparser.add_argument('size', nargs='?')
    subparser = subparsers.add_parser('gsettings')
    subparser.add_argument('desktop', nargs='?')
    subparser.add_argument('size', nargs='?')

    args = vars(parser.parse_args())
    set_logger()

    command = args.pop('command')
    commands = {
        None: parser.usage,
        'shuffle': shuffle.select_random_wallpaper,
        'gsettings': gsettings,
    }

    print(commands[command](**args))

if __name__ == '__main__':
    main()



#!/usr/bin/env python
from setuptools import setup, find_packages


def read(file_path):
    with open(file_path) as fp:
        return fp.read()


setup(
    name='desktopography',
    version='1.1',
    description="A simple desktopography.net wallpaper retriever",
    long_description=read('Readme.rst'),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: X11 Applications',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Desktop Environment',
        'Topic :: Utilities',
    ],
    keywords=['desktopography', 'wallpapers'],
    author='Fabien Bochu',
    author_email='fabien.bochu+desktopography@gmail.com',
    url='https://gitlab.com/fbochu/desktopography',
    license='BSD',
    packages=find_packages(where='src'),
    package_dir={'': str('src')},
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'BeautifulSoup4',
        'requests',
    ],
    entry_points={
        'console_scripts': (
            'desktopography = desktopography.cli:main',
        ),
    },
)
